API docs for “spamfighter.core.commands.errors.FirewallSyntaxError”

# Class s.c.c.e.FirewallSyntaxError(BaseCommandException):

Part of spamfighter.core.commands.errors View Source View In Hierarchy

Ошибка синтаксиса правил firewall.

Method | __init__ | Undocumented

Inherited from BaseCommandException:

Method | getCode | Undocumented
Method | getMessage | Undocumented
Method | __str__ | Undocumented

def __init__(self, message): (source)
overrides spamfighter.core.commands.errors.BaseCommandException.__init__
Undocumented